@@ -244,13 +244,15 @@ class JsonObject:
         return None
 
     def __dataframe_values__(self):
-        return [v.to_dataframe() if isinstance(v, (JsonList, JsonObject)) else v for v in self.get_values()]
+        return [v.to_dataframe(recursive=True) if isinstance(v, (JsonList, JsonObject)) else v for v in self.get_values()]
 
-    def to_dataframe(self):
+    def to_dataframe(self, recursive: bool = False):
         from pandas import DataFrame
         columns = self.get_columns()
-        return DataFrame([self.__dataframe_values__()], columns=columns)
-
+        if recursive:
+            return DataFrame([self.__dataframe_values__()], columns=columns)
+        else:
+            return DataFrame([self.get_values()], columns=columns)
 
 
 class SortOrder:
@@ -519,11 +521,19 @@ class JsonList(list):
                 ni[c] = row[i]
             self.append(ni)
 
-    def to_dataframe(self):
+    def to_dataframe(self, recursive: bool = False):
         from pandas import DataFrame
         if issubclass(self.list_type, JsonObject):
-            columns = self.list_type().get_columns()
-            return DataFrame([i.__dataframe_values__() for i in self], columns=columns)
+            if self.list_type is JsonObject:
+                if len(self) == 0:
+                    return DataFrame()
+                columns = self[0].get_columns()
+            else:
+                columns = self.list_type().get_columns()
+            if recursive:
+                return DataFrame([i.__dataframe_values__() for i in self], columns=columns)
+            else:
+                return DataFrame([i.get_values() for i in self], columns=columns)
         else:
             return DataFrame(self)
 
